const path = require("path");

module.exports = grunt => {
    grunt.initConfig({
        pkg: grunt.file.readJSON("package.json"),
        clean: {
            default: ["dist/"],
        },
        focus: {
            dev: {
                include: ["css", "js"],
            },
        },
        webpack: {
            options: {
                entry: "./src/main/js/Template.js",
                module: {
                    rules: [
                        {
                            test: /\.js$/i,
                            exclude: /node_modules/,
                        },
                        {
                            test: /\.css$/i,
                            use: ["style-loader", "css-loader"],
                        },
                    ],
                },
                resolve: {
                    extensions: [".js", ".css"],
                },
                output: {
                    library: "fwdekker-template",
                    libraryTarget: "umd",
                    filename: "index.js",
                    path: path.resolve(__dirname, "dist"),
                }
            },
            dev: {
                mode: "development",
                devtool: "inline-source-map",
            },
            deploy: {
                mode: "production",
            },
        },
        watch: {
            css: {
                files: ["src/main/**/*.css"],
                tasks: ["webpack:dev"],
            },
            js: {
                files: ["src/main/**/*.js"],
                tasks: ["webpack:dev"],
            },
        },
    });

    grunt.loadNpmTasks("grunt-contrib-clean");
    grunt.loadNpmTasks("grunt-contrib-watch");
    grunt.loadNpmTasks("grunt-focus");
    grunt.loadNpmTasks("grunt-webpack");

    grunt.registerTask("dev", ["webpack:dev"]);
    grunt.registerTask("dev:server", ["dev", "focus:dev"]);
    grunt.registerTask("deploy", ["webpack:deploy"]);

    grunt.registerTask("default", ["dev"]);
};
